/*
  In App.xaml:
  <Application.Resources>
      <vm:ViewModelLocator xmlns:vm="clr-namespace:WpfNavigation"
                           x:Key="Locator" />
  </Application.Resources>
  
  In the View:
  DataContext="{Binding Source={StaticResource Locator}, Path=ViewModelName}"

  You can also use Blend to do all this with the tool's support.
  See http://www.galasoft.ch/mvvm
*/

using CommonServiceLocator;
using GalaSoft.MvvmLight.Ioc;

namespace WpfNavigation.ViewModel
{
    /// <summary>
    /// This class contains static references to all the view models in the
    /// application and provides an entry point for the bindings.
    /// </summary>
    public class ViewModelLocator
    {
        /// <summary>
        /// Initializes a new instance of the ViewModelLocator class.
        /// </summary>
        public ViewModelLocator()
        {
            ServiceLocator.SetLocatorProvider(() => SimpleIoc.Default);           
            SimpleIoc.Default.Register<MainViewModel>();

            //The Views
            SimpleIoc.Default.Register<View1ViewModel>();
            SimpleIoc.Default.Register<View2ViewModel>();
            SimpleIoc.Default.Register<View3ViewModel>();
        }

        private static ViewModelLocator _instance = null;

        public static ViewModelLocator Instance
        {
            get
            {
                if (_instance == null) _instance = new ViewModelLocator();
                return _instance;
            }
        }


        public MainViewModel Main
        {
            get
            {
                return ServiceLocator.Current.GetInstance<MainViewModel>();
            }
        }

        public View1ViewModel View1
        {
            get
            {
                return ServiceLocator.Current.GetInstance<View1ViewModel>();
            }
        }

        public View2ViewModel View2
        {
            get
            {
                return ServiceLocator.Current.GetInstance<View2ViewModel>();
            }
        }


        public View3ViewModel View3
        {
            get
            {
                return ServiceLocator.Current.GetInstance<View3ViewModel>();
            }
        }


        public static void Cleanup()
        {
            
        }
    }
}